@@ -12,7 +12,7 @@
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the Apache License, version 2.0 as published by the
 # Apache Software Foundation.
-# No warranty expressed or implied. See the file LICENSE.ASF-2 for details.
+# No warranty expressed or implied. See the file ‘LICENSE.ASF-2’ for details.
 
 """ Daemon runner library.
     """
@@ -25,8 +25,7 @@ import signal
 import errno
 
 from . import pidlockfile
-
-from daemon import DaemonContext
+from .daemon import DaemonContext
 
 
 class DaemonRunnerError(Exception):
@@ -73,7 +72,7 @@ class DaemonRunner(object):
 
             * `run`: Callable that will be invoked when the daemon is
               started.
-            
+
             """
         self.parse_args()
         self.app = app
@@ -225,7 +224,7 @@ def is_pidfile_stale(pidfile):
             os.kill(pidfile_pid, signal.SIG_DFL)
         except OSError, exc:
             if exc.errno == errno.ESRCH:
-                # The specified PID does not exist
+                # The specified PID does not exist.
                 result = True
 
     return result
